@@ -7,6 +7,7 @@ from typing import List
 from invoke import run
 
 from semantic_release import ImproperConfigurationError
+from semantic_release.settings import config
 
 from .helpers import LoggedFunction
 
@@ -34,11 +35,16 @@ def upload_to_pypi(
 
     # Attempt to get an API token from environment
     token = os.environ.get("PYPI_TOKEN")
+    username = None
+    password = None
     if not token:
         # Look for a username and password instead
         username = os.environ.get("PYPI_USERNAME")
         password = os.environ.get("PYPI_PASSWORD")
-        if not (username or password):
+        home_dir = os.environ.get("HOME", "")
+        if not (username or password) and (
+            not home_dir or not os.path.isfile(os.path.join(home_dir, ".pypirc"))
+        ):
             raise ImproperConfigurationError(
                 "Missing credentials for uploading to PyPI"
             )
@@ -48,10 +54,17 @@ def upload_to_pypi(
         username = "__token__"
         password = token
 
+    repository = config.get("repository", None)
+    repository_arg = f" -r '{repository}'" if repository else ""
+
+    username_password = (
+        f"-u '{username}' -p '{password}'" if username and password else ""
+    )
+
     dist = " ".join(
         ['"{}/{}"'.format(path, glob_pattern.strip()) for glob_pattern in glob_patterns]
     )
 
     skip_existing_param = " --skip-existing" if skip_existing else ""
 
-    run(f"twine upload -u '{username}' -p '{password}'{skip_existing_param} {dist}")
+    run(f"twine upload {username_password}{repository_arg}{skip_existing_param} {dist}")
